@@ -3,7 +3,7 @@ use core::fmt::{self, Display};
 use serde::{Deserialize, Serialize};
 
 /// ABCI info
-#[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
+#[derive(Clone, Debug, Default, Deserialize, Eq, PartialEq, Serialize)]
 pub struct Info(String);
 
 impl AsRef<str> for Info {
@@ -17,9 +17,3 @@ impl Display for Info {
         write!(f, "{}", self.0)
     }
 }
-
-impl Default for Info {
-    fn default() -> Self {
-        Self(String::new())
-    }
-}
