@@ -130,7 +130,7 @@ where
 }
 
 /// Codespace
-#[derive(Clone, Debug, Deserialize, Eq, PartialEq, Serialize)]
+#[derive(Clone, Debug, Default, Deserialize, Eq, PartialEq, Serialize)]
 pub struct Codespace(String);
 
 impl AsRef<str> for Codespace {
@@ -144,9 +144,3 @@ impl Display for Codespace {
         write!(f, "{}", self.0)
     }
 }
-
-impl Default for Codespace {
-    fn default() -> Self {
-        Self(String::new())
-    }
-}
